@@ -1,6 +1,6 @@
 package ShardedKV::Error;
 {
-  $ShardedKV::Error::VERSION = '0.15';
+  $ShardedKV::Error::VERSION = '0.16';
 }
 use Moose;
 extends 'Throwable::Error';
@@ -34,13 +34,15 @@ ShardedKV::Error - Provides an error class for managing exceptions
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 DESCRIPTION
 
 ShardedKV::Error provides a base error class for exceptions that occur in storage backends. Since ShardedKV abstracts away which storage backend is in use, this class provides a couple of attributes that help identify problem endpoints and storage types. There are three subclasses that also identify what sort of operation failed: L<ShardedKV::Error::ConnectFail>, L<ShardedKV::Error::ReadFail>, L<ShardedKV::Error::WriteFail>. 
 
-=public_attribute storage_type
+=head1 PUBLIC ATTRIBUTES
+
+=head2 storage_type
 
   (is: ro, isa: enum(redis, mysql), required)
 
@@ -48,7 +50,7 @@ storage_type allows for consumers of ShardedKV to know what threw the exception
 without knowing which storage backend was in use. Since we only support two
 types, it is sufficient to simply have an enum for those two types.
 
-=public_attribute endpoint
+=head2 endpoint
 
   (is: ro, isa: Str, required)
 
